Core Module
===========

.. currentmodule:: toolscore.core

The core module provides the main evaluation functions and result container.

Main Functions
--------------

.. autofunction:: evaluate_trace

.. autofunction:: load_gold_standard

.. autofunction:: load_trace

Result Container
----------------

.. autoclass:: EvaluationResult
   :members:
   :undoc-members:

Internal Functions
------------------

.. autofunction:: _detect_format
